@echo off
setlocal
set startfolder=%~dp0

echo Building database environment from scratch...

rem Setting common log and ini files to be used in all scripts down there
if not defined CnfFileName set CnfFileName=%startfolder%\DBCreator.ini

rem Getting configuration values from INI file.
for /F "usebackq eol=;" %%s in ("%CnfFileName%") do set %%s

rem If the instance name was given - it is included into the server name
if "%SqlInstanceName%" gtr "" set SqlInstanceName=\%SqlInstanceName%






rem Removing any remainders from the previous runs:
if exist "%startfolder%\AdHocDBNameMapping.tmp"  del "%startfolder%\AdHocDBNameMapping.tmp"


rem Parsing input parameters detect their names and values

if "%1" equ ""  (
    echo No parameters were passed, default values are used
    goto ParParseOut
)

:ParseNextParameter

rem Detecting database name mapping parameter

if "%1" equ "/DbNameMapping" (
  if not "%2" gtr "" (
    echo ERROR: DbNameMapping key found, but no original database name was specified.
    goto ScriptUsageMsg
) 
  if not "%3" gtr "" (
    echo ERROR: DbNameMapping key found, but no target database name was specified.
    goto ScriptUsageMsg
) 

echo DbNameMapping parameter was found. Script will use database "%3" as "%2".
if not exist "%startfolder%\AdHocDBNameMapping.tmp" (
    echo ^<LogicalEnvironment Name="AdHoc DB Name"^> > "%startfolder%\AdHocDBNameMapping.tmp"
)

echo ^<Database NameInConfig="%2" NameOnServer="%3" ^/^> >> "%startfolder%\AdHocDBNameMapping.tmp"

if "%4" gtr "" (
    shift
    shift
    shift
    goto ParseNextParameter
) else (
 echo No more parameters found
 goto ParParseOut
)
)

rem If there are more parameters - process them too in a way similar to the previous one

rem At this point there must be no unprocessed parameters found
if "%1" gtr "" (
    echo Unknown parameters received: %*
    goto ScriptUsageMsg
)
rem Here may go more parameter processsing similar to the previous one

:ParParseOut
if exist "%startfolder%\AdHocDBNameMapping.tmp" (
    echo One or more target database name was defined by input parameter
    echo ^<^/LogicalEnvironment^>  >> "%startfolder%\AdHocDBNameMapping.tmp"
    set DbNameMappingFile=AdHocDBNameMapping.tmp
)

rem End of parameter-based activity
"Utils\DBCreator.vbe" create /sqlservername:%MachineName%%SqlInstanceName% /envconfig:"%EnvConfigFile%" /dbnamemapping:"%DbNameMappingFile%" 

set RC=%ERRORLEVEL%
echo %RC%

rem Cleaning up...
if exist "%startfolder%\AdHocDBNameMapping.tmp"  del "%startfolder%\AdHocDBNameMapping.tmp"

endlocal
exit /B %RC%


:ScriptUsageMsg
echo ===============================================================================
echo Script updates database(s) structure with changes registered in the change log
echo Input parameters:
echo.
echo /DbNameMapping {OriginalDatabaseName}={TargetDatabaseName} 
echo   Points script to a copy of database with different name. 
echo   More than one database mapping may be spefied.
echo   Examples:
echo     /DbNameMapping AdvWorks=AdventureWorksTestCopy002
echo     /DbNameMapping FBIAgents=SuperSecret01 /DbNameMapping CIAAgents=SuperSecret02


endlocal
exit /B 0