SET  ansi_nulls, ansi_padding, ansi_warnings, concat_null_yields_null,
quoted_identifier ON ;

SET  numeric_roundabort OFF ;
GO
IF EXISTS ( SELECT
                    OBJECT_ID
                FROM
                    sys.triggers
                WHERE
                    name = 'DdlChangesWatchdog' ) 
    BEGIN
        SET NOEXEC ON
    END ;
GO
PRINT 'DdlChangesWatchdog: creating a stub' ;
go
CREATE TRIGGER DdlChangesWatchdog ON DATABASE
    FOR DROP_INDEX
AS
    BEGIN
        PRINT 'DdlChangesWatchdog: not implemented yet'
    END
go
SET NOEXEC OFF


print 'DdlChangesWatchdog: trigger creation script started' ;
GO
/*******************************************************************************
Name:        "DDL.Database version modification on DB change.sql"
Description: 
    Trigger modifies database build version on any database structure modification
    event. 
    
    Is to provide an evidence of the database modification since the db was
    marked with the build number by the DBBuilder.


    Please mention that the script contains _ALL_ the events with Database Scope.
    Those not considered for the trigger are commented-out.
    Please DO NOT REMOVE them - they will facilitate the support in the future.
    
    
Input Parameters:
    None    
Returns:
    Nothing

Modification History
Sr  Date (MDY)  Modified By             Reason
1   ??/??/????  Alexander Karmanov      Initial version
*******************************************************************************/
alter trigger DdlChangesWatchdog on database
    for
--CREATE_APPLICATION_ROLE
--, ALTER_APPLICATION_ROLE
--, DROP_APPLICATION_ROLE
        create_assembly
        , alter_assembly
        , drop_assembly 
--,ALTER_AUTHORIZATION_DATABASE
        , create_certificate
        , alter_certificate
        , drop_certificate
        , create_contract
        , drop_contract
--,GRANT_DATABASE
--, DENY_DATABASE
--, REVOKE_DATABASE
        , create_event_notification
        , drop_event_notification
        , create_function
        , alter_function
        , drop_function
        , create_index
        , alter_index
        , drop_index
        , create_message_type
        , alter_message_type
        , drop_message_type
        , create_partition_function 
--, ALTER_PARTITION_FUNCTION
        , drop_partition_function
        , create_partition_scheme 
--, ALTER_PARTITION_SCHEME
        , drop_partition_scheme
        , create_procedure
        , alter_procedure
        , drop_procedure
        , create_queue
        , alter_queue
        , drop_queue
--,CREATE_REMOTE_SERVICE_BINDING
--, ALTER_REMOTE_SERVICE_BINDING
--, DROP_REMOTE_SERVICE_BINDING
--,CREATE_ROLE
--, ALTER_ROLE
--, DROP_ROLE
--,CREATE_ROUTE
--, ALTER_ROUTE
--, DROP_ROUTE
        -- , create_schema -- THIS ONE IS EXCLUDED TEMPORARILY - until the deployment script is fixed.
        , alter_schema
        , drop_schema
        , create_service
        , alter_service
        , drop_service
--,CREATE_STATISTICS
--, DROP_STATISTICS
--, UPDATE_STATISTICS
        , create_synonym
        , drop_synonym
        , create_table
        , alter_table
        , drop_table
        , create_trigger
        , alter_trigger
        , drop_trigger
        , create_type
        , drop_type
--,CREATE_USER
--, ALTER_USER
--, DROP_USER
        , create_view, alter_view, drop_view, create_xml_schema_collection,
        alter_xml_schema_collection, drop_xml_schema_collection
as
BEGIN
    DECLARE
        @cur_db_version VARCHAR(7500)
      , @new_db_version VARCHAR(7500)
      , @attribute_exists BIT ;
    
    SELECT
            @cur_db_version = CAST(value AS VARCHAR(7500))
          , @attribute_exists = CASE WHEN name IS NOT NULL THEN 1
                                     ELSE 0
                                END
        FROM
            sys.fn_listextendedproperty('database_build_number', NULL, NULL,
                                        NULL, NULL, NULL, NULL) ;

    SET @new_db_version = LEFT(@cur_db_version + '; modified on '
                               + CONVERT (VARCHAR(26), GETDATE(), 126)
                               + ' by ' + SUSER_SNAME() + ': '
                               + CAST(eventdata() AS VARCHAR(MAX)), 7500) ;
    
    IF ISNULL(@attribute_exists, 0) = 0 
        BEGIN
            EXEC sys.sp_addextendedproperty @name = N'database_build_number',
                @value = N'UNKNOWN' ;
        END ;
    ELSE 
        BEGIN
            EXEC sys.sp_updateextendedproperty @name = N'database_build_number',
                @value = @new_db_version ;
        END ;;
    
    ;
END ;

;;
GO
print 'DdlChangesWatchdog: trigger creation script finished' ;