SET ANSI_NULLS, ANSI_PADDING, ANSI_WARNINGS, CONCAT_NULL_YIELDS_NULL, QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
go
IF OBJECT_ID('dbo.ToggleDdlWatchdogTriggerState') IS NOT NULL 
    SET NOEXEC ON
go
PRINT 'dbo.ToggleDdlWatchdogTriggerState: creating procedure stub'
go

CREATE PROCEDURE dbo.ToggleDdlWatchdogTriggerState
AS 
    PRINT 'dbo.ToggleDdlWatchdogTriggerState: not implemented yet.'
go
SET NOEXEC OFF
go
PRINT 'dbo.ToggleDdlWatchdogTriggerState: procedure creation script started'            
go
/*******************************************************************************
Name:        dbo.ToggleDdlWatchdogTriggerState
Description: 
    Procedure toggles on/off a database trigger that watches for database 
    structure changes and invalidates build number if detects any of them.
    
    To be used by the data archiving process - in that process 
    stating (out) tables are created and dropped. Such operations would
    be captured by that trigger, so it should be temporarily disabled.
        
Input Parameters:
    New trigger state - on or off.    
Returns:
    Nothing

Modification History
Sr  Date (MDY)  Modified By             Reason
1   ??/??/????  Alexander Karmanov      Initial version
*******************************************************************************/
ALTER PROCEDURE dbo.ToggleDdlWatchdogTriggerState
    @NewTriggerState VARCHAR(3)
AS 
    BEGIN
        SET nocount ON
        DECLARE
            @StateOn VARCHAR(3)
          , @StateOff VARCHAR(3)
        SELECT
                @StateOn = 'on'
              , @StateOff = 'off'
        
    -- check the flag, fail if the value is not known
        IF (@NewTriggerState = @StateOn) 
            BEGIN
                ENABLE TRIGGER DdlChangesWatchdog ON DATABASE
            END
        ELSE 
            IF (@NewTriggerState = @StateOff) 
                BEGIN
                    DISABLE TRIGGER DdlChangesWatchdog ON DATABASE
                END
            ELSE 
                BEGIN
                    RAISERROR('dbo.ToggleDdlWatchdogTriggerState: Given flag (%s) is not known', 16, 1, @NewTriggerState)
                    RETURN -1
                END
    END
go

exec sys.sp_MS_marksystemobject 'dbo.ToggleDdlWatchdogTriggerState'
go
PRINT 'dbo.ToggleDdlWatchdogTriggerState: procedure creation script finished'